@@ -15,6 +15,7 @@ import (
 	ver "github.com/k1LoW/tbls/version"
 	"github.com/minio/pkg/wildcard"
 	"github.com/pkg/errors"
+	"github.com/samber/lo"
 )
 
 const DefaultDocPath = "dbdoc"
@@ -318,7 +319,7 @@ func (c *Config) validate() error {
 	if err := c.checkVersion(ver.Version); err != nil {
 		return err
 	}
-	if !contains(SupportERFormat, c.ER.Format) {
+	if !lo.Contains(SupportERFormat, c.ER.Format) {
 		return fmt.Errorf("unsupported ER format: %s", c.ER.Format)
 	}
 	for i, v := range c.Viewpoints {
@@ -328,6 +329,14 @@ func (c *Config) validate() error {
 		if v.Desc == "" {
 			return fmt.Errorf("viewpoints[%d] description is required", i)
 		}
+		for j, g := range v.Groups {
+			if g.Name == "" {
+				return fmt.Errorf("viewpoints[%d].groups[%d] name is required", i, j)
+			}
+			if g.Desc == "" {
+				return fmt.Errorf("viewpoints[%d].groups[%d] description is required", i, j)
+			}
+		}
 	}
 
 	return nil
@@ -433,7 +442,7 @@ func (c *Config) ModifySchema(s *schema.Schema) error {
 	// set Viewpoints
 	// viewpoints should be created using as complete a schema as possible
 	for _, v := range c.Viewpoints {
-		cs, err := s.Clone()
+		cs, err := s.CloneWithoutViewpoints()
 		if err != nil {
 			return err
 		}
@@ -444,12 +453,40 @@ func (c *Config) ModifySchema(s *schema.Schema) error {
 		}); err != nil {
 			return err
 		}
+		groups := []*schema.ViewpointGroup{}
+		tables := lo.Map(cs.Tables, func(t *schema.Table, _ int) string {
+			return t.Name
+		})
+		for _, g := range v.Groups {
+			gt, _, err := cs.SepareteTablesThatAreIncludedOrNot(&schema.FilterOption{
+				Include:       g.Tables,
+				IncludeLabels: g.Labels,
+			})
+			if err != nil {
+				return err
+			}
+			groups = append(groups, &schema.ViewpointGroup{
+				Name:   g.Name,
+				Desc:   g.Desc,
+				Tables: g.Tables,
+				Labels: g.Labels,
+				Color:  g.Color,
+			})
+			left, right := lo.Difference(tables, lo.Map(gt, func(t *schema.Table, _ int) string {
+				return t.Name
+			}))
+			if len(right) > 0 {
+				return fmt.Errorf("viewpoint group '%s' has duplicate tables %v", g.Name, right)
+			}
+			tables = left
+		}
 		s.Viewpoints = s.Viewpoints.Merge(&schema.Viewpoint{
 			Name:     v.Name,
 			Desc:     v.Desc,
 			Labels:   v.Labels,
 			Tables:   v.Tables,
 			Distance: v.Distance,
+			Groups:   groups,
 			Schema:   cs,
 		})
 	}
@@ -787,7 +824,7 @@ func detectCardinality(s *schema.Schema) error {
 					continue
 				}
 				for _, cc := range c.Columns {
-					if !contains(columns, cc) {
+					if !lo.Contains(columns, cc) {
 						continue LL
 					}
 				}
@@ -862,12 +899,3 @@ func match(s []string, e string) bool {
 	_, m := matchLength(s, e)
 	return m
 }
-
-func contains(s []string, e string) bool {
-	for _, v := range s {
-		if e == v {
-			return true
-		}
-	}
-	return false
-}
